==> parole-0.1.95.tar.bz2: parole-0.1.95/src/parole-plugins-manager.h <==
/*
 * * Copyright (C) 2009 Ali <aliov@xfce.org>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __PAROLE_PLUGINS_MANAGER_H
#define __PAROLE_PLUGINS_MANAGER_H

#include <glib-object.h>
#include <parole/parole-provider-player.h>

G_BEGIN_DECLS

#define PAROLE_TYPE_PLUGINS_MANAGER        (parole_plugins_manager_get_type () )
#define PAROLE_PLUGINS_MANAGER(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), PAROLE_TYPE_PLUGINS_MANAGER, ParolePluginsManager))
#define PAROLE_IS_PLUGINS_MANAGER(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), PAROLE_TYPE_PLUGINS_MANAGER))

typedef struct ParolePluginsManagerPrivate ParolePluginsManagerPrivate;

typedef struct
{
    GObject         		     parent;
    ParolePluginsManagerPrivate     *priv;
    
} ParolePluginsManager;

typedef struct
{
    GObjectClass 		    parent_class;
    
} ParolePluginsManagerClass;

GType        			    parole_plugins_manager_get_type       (void) G_GNUC_CONST;

ParolePluginsManager               *parole_plugins_manager_new            (gboolean load_plugins);

ParolePluginsManager 		   *parole_plugins_manager_get 		  (void);

void 				    parole_plugins_manager_pack 	  (ParolePluginsManager *manager, 
									   GtkWidget *widget, 
									   const gchar *title,
									   ParolePluginContainer container);

G_END_DECLS

#endif /* __PAROLE_PLUGIN_MANAGER_H */

==> parole_0.3.0.3.orig.tar.bz2: parole-0.3.0.3/src/parole-plugins-manager.h <==
/*
 * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __PAROLE_PLUGINS_MANAGER_H
#define __PAROLE_PLUGINS_MANAGER_H

#include <glib-object.h>
#include <src/misc/parole-provider-player.h>

G_BEGIN_DECLS

#define PAROLE_TYPE_PLUGINS_MANAGER        (parole_plugins_manager_get_type () )
#define PAROLE_PLUGINS_MANAGER(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), PAROLE_TYPE_PLUGINS_MANAGER, ParolePluginsManager))
#define PAROLE_IS_PLUGINS_MANAGER(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), PAROLE_TYPE_PLUGINS_MANAGER))

typedef struct ParolePluginsManagerPrivate ParolePluginsManagerPrivate;

typedef struct
{
    GObject         		     parent;
    ParolePluginsManagerPrivate     *priv;
    
} ParolePluginsManager;

typedef struct
{
    GObjectClass 		    parent_class;
    
} ParolePluginsManagerClass;

GType        			    parole_plugins_manager_get_type       (void) G_GNUC_CONST;

ParolePluginsManager               *parole_plugins_manager_new            (gboolean load_plugins);

ParolePluginsManager 		   *parole_plugins_manager_get 		  (void);

void				    parole_plugins_manager_load		  (ParolePluginsManager *manager);

void 				    parole_plugins_manager_pack 	  (ParolePluginsManager *manager, 
									   GtkWidget *widget, 
									   const gchar *title,
									   ParolePluginContainer container);

G_END_DECLS

#endif /* __PAROLE_PLUGIN_MANAGER_H */
